<?php

namespace Schaffen\Gef\Models;

use App\Http\Controllers\Api\Ged\DocumentoModuloService;
use App\Models\Cadastro\Pessoa;
use App\Models\Estoque\Cadastro\LocalEstoque;
use App\Models\Financeiro\CentroCusto;
use App\Models\Ged\DocumentoModulo;
use Illuminate\Database\Eloquent\Model;
use Prettus\Repository\Contracts\Transformable;
use Prettus\Repository\Traits\TransformableTrait;

/**
 * Class Veiculo.
 *
 * @package namespace Schaffen\Gef\Models;
 */
class Veiculo extends Model implements Transformable
{


   public static $tipos_combustivel =[

      1 => 'Gasolina comum',
      2 => 'Gasolina aditivada',
      3 => 'Gasolina premium',
      4 => 'Gasolina formulada',
      5 => 'Etanol',
      6 => 'Etanol aditivado',
      7 => 'GNV (Gás Natural Veicular)',
      8 => 'Diesel',
      9 => 'Diesel S-10',
      10 => 'Diesel aditivado',
      11 => 'Diesel Premium',
      12 => 'Flex'

   ];

   use TransformableTrait;

   public $with = ["centro_custo"];
   public $timestamps = false;
   protected $table = "frota.veiculo";
   protected $primaryKey = "vei_codigo";

   /**
    * The attributes that are mass assignable.
    *
    * @var array
    */

   public  static $prefix = 'vei_';
   protected $fillable = [
       "vei_placa"
      ,"vei_ano"
      ,"vei_identificador"
      ,"vei_descricao"
      ,"vei_km_inicial"
      ,"vei_modelo"
      ,"vei_municipio"
      ,"vei_uf"
      ,"vei_cor"
      ,"vei_numero"
      ,"vei_renavam"
      ,"vei_chassi"
      ,"vei_tipo_combustivel"
      ,"vei_fk_loe_codigo"
      ,"vei_fk_proprietario_pes_codigo"
      ,"vei_fk_seguradora_pes_codigo"
      ,"vei_status"
      ,"vei_fk_ccu_codigo"
      ,"vei_fk_mar_codigo"
      ,"vei_fk_vendedor_pes_codigo"
      ,"vei_tipo_frota"
   ];


   public function proprietario(){
      return $this->belongsTo(Pessoa::class, 'vei_fk_proprietario_pes_codigo');
   }
   public function seguradora(){
      return $this->belongsTo(Pessoa::class, 'vei_fk_seguradora_pes_codigo');
   }
   public function vendedor(){
      return $this->belongsTo(Pessoa::class, 'vei_fk_vendedor_pes_codigo');
   }

   public function local_estoque(){
      return $this->belongsTo(LocalEstoque::class, 'vei_fk_loe_codigo');
   }

   public function centro_custo(){
      return $this->belongsTo(CentroCusto::class,'vei_fk_ccu_codigo');
   }
   public function documentoModulo(){
      return $this->hasMany(DocumentoModulo::class, "dom_codigo_identificador", "vei_codigo")
         ->where("dom_identificador_owner", DocumentoModuloService::MODULO_VEICULO)
         ->with("anexos");
   }

}
